@@ -133,7 +133,8 @@ types_converter_dict = {
             "bigint": "Int32",
             "numeric": "Float32",
             "double_precision": "Float64",
-            "double precision": "Float64"
+            "double precision": "Float64",
+            "user-defined": "String"
         },
         "default": {"false": 0, "true": 1},
     },
